<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>
 
<body <?php body_class('align-logo-center'); ?>>
<?php 
    if ( function_exists( 'wp_body_open' ) ) {
        wp_body_open();
    } else {
        do_action( 'wp_body_open' );
    } 
?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'magoblog' ); ?></a>
    
    <div class="menu-overlay"></div>
    <?php if ( get_theme_mod( 'magoblog_topbar' ) == true && has_nav_menu( 'secondary' ) ): ?>
        <div id="top-navigation" class="relative">
            <div class="wrapper">
                <button class="button-menu-toggle" aria-controls="secondary-menu" aria-expanded="false">
                    <svg viewBox="0 0 40 40" class="icon-menu">
                        <rect y="7" width="40" height="2"></rect>
                        <rect y="19" width="40" height="2"></rect>
                        <rect y="31" width="40" height="2"></rect>
                    </svg>
                    <svg viewBox="0 0 612 612" class="icon-close">
                        <polygon points="612,36.004 576.521,0.603 306,270.608 35.478,0.603 0,36.004 270.522,306.011 0,575.997 35.478,611.397 
                        306,341.411 576.521,611.397 612,575.997 341.459,306.011"></polygon>
                    </svg>
                </button>

                <nav id="secondary-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Secondary Menu', 'magoblog' );?>">
                    <?php 
                        $social_menu = '';
                        if ( has_nav_menu( 'social' ) ) :
                            
                            $social_menu .= '<li class="social-menu-item"><div class="social-icons">';
                            $social_menu .= wp_nav_menu( array(
                                                'theme_location'  => 'social',
                                                'menu_class'      => 'social-icons',
                                                'container_class' => 'social-menu',
                                                'depth'           => 1,
                                                'echo'            => false,
                                                'link_before'     => '<span class="screen-reader-text">',
                                                'link_after'      => '</span>' . blogoholic_get_svg( array( 'icon' => 'chain' ) ),
                                            ) );
                            $social_menu .= '</div></li>';
                        endif;       
                    
                        wp_nav_menu( array(
                            'theme_location' => 'secondary',
                            'container' => false,
                            'menu_class' => 'menu nav-menu',
                            'menu_id' => 'secondary-menu',
                            'echo' => true,
                            'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $social_menu . '</ul>',
                        ) );
                    ?>   
                </nav>
            </div>
        </div>

    <?php endif ?>

    <header id="masthead" class="site-header <?php echo esc_attr( get_theme_mod( 'magoblog_header_style') ) ; ?> <?php echo esc_attr( get_theme_mod( 'magoblog_header_display') ) ; ?>" role="banner">  
        <div class="wrapper">
            <div class="header-banner">     

                <div class="site-branding">
                    <?php if ( has_custom_logo() ) : ?>
                        <div class="site-logo">
                            <?php the_custom_logo(); ?>
                        </div>
                    <?php endif; ?>
                    <?php if ( get_theme_mod( 'magoblog_header_text_display', true ) == true ): ?>
                        <div id="site-identity">
                            <?php
                            if ( is_front_page() ) : ?>
                                <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                            <?php else : ?>
                                <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                            <?php
                            endif;

                            $description = get_bloginfo( 'description', 'display' );
                            if ( $description || is_customize_preview() ) : ?>
                                <p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
                            <?php
                            endif; ?>
                        </div>
                    <?php endif ?>
                    
                </div>
                <?php if ( !empty( get_theme_mod( 'magoblog_header_ads_image', '' ) ) ): ?>
                    <div class="site-advertisement">
                        <a href="<?php echo esc_url( get_theme_mod( 'magoblog_header_ads_image_url', '#' ) ) ; ?>"><img src="<?php echo esc_url( get_theme_mod( 'magoblog_header_ads_image', '' ) ); ?>" height="200" ></a>                        
                    </div>
                <?php endif; ?>
            </div>
            <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
            <svg viewBox="0 0 40 40" class="icon-menu">
                <g>
                    <rect y="7" width="40" height="2"/>
                    <rect y="19" width="40" height="2"/>
                    <rect y="31" width="40" height="2"/>
                </g>
            </svg>
            <svg viewBox="0 0 612 612" class="icon-close">
                <polygon points="612,36.004 576.521,0.603 306,270.608 35.478,0.603 0,36.004 270.522,306.011 0,575.997 35.478,611.397 
                306,341.411 576.521,611.397 612,575.997 341.459,306.011"/>
            </svg>
        </button>
        <?php if ( has_nav_menu( 'primary' ) ) : ?>
            <nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Primary Menu', 'magoblog' );?>">
                
                <?php
                    $search_html = '';
                    if ( get_theme_mod( 'magoblog_topbar_search' ) == true ) :
                        $search_html .= '
                            <li>
                                <div id="search">' .
                                    get_search_form( $echo = false ) .
                                '</div><!-- #search -->
                            </li>';
                    endif;

                    wp_nav_menu( array(
                        'theme_location' => 'primary',
                        'menu_id'        => 'primary-menu',
                        'menu_class'     => 'menu nav-menu',
                        'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search_html . '</ul>',
                    ) );
                ?>
            </nav>
        <?php elseif( current_user_can( 'edit_theme_options' ) ): ?>
            <nav class="main-navigation" id="site-navigation">
                <ul id="primary-menu" class="menu nav-menu">
                    <li><a href="<?php echo esc_url( admin_url( 'nav-menus.php' ) ); ?>"><?php echo esc_html__( 'Add a menu', 'magoblog' );?></a></li>
                </ul>
            </nav>
        <?php endif; ?>  
        </div>     
            
    </header>

	<div id="content" class="site-content">
